import { useSession } from "next-auth/react";

import { Icons } from "@/components/icons";
import { Button } from "@/components/ui/button";
import { useLike } from "../../hooks/use-like";
import { IGweet } from "../../types";

export const LikeButton = ({
  gweet,
  showStats = false,
}: {
  gweet?: IGweet;
  smallIcons?: boolean;
  showStats?: boolean;
}) => {
  const { data: session } = useSession();
  const hasLiked = gweet?.likes?.some(
    (like) => like.userId === session?.user?.id,
  );

  const mutation = useLike({
    gweetAuthorId: gweet?.user?.id,
    sessionOwnerId: session?.user?.id,
  });

  return (
    <Button
      onClick={(e) => {
        e.stopPropagation();
        if (!session) {
          return;
        }
        mutation.mutate({ gweetId: gweet?.id, userId: session?.user?.id });
      }}
      variant="ghost" size="lg" className="px-6 py-3 hover:bg-red-800"
    >
      {hasLiked ?
        <Icons.heart className="h-5 w-5 fill-red-600 text-red-600" />
        : <Icons.heart className="h-5 w-5" />
      }

      <span className="pl-2">
        {showStats && gweet?.likes && gweet?.likes?.length > 0 && (
          <span className="">{gweet?.likes?.length}</span>
        )}
      </span>
    </Button>
  );
};