"use client"

import { usePathname, useRouter } from "next/navigation";

import { CreateGweetWrapper } from "@/components/create-gweet";
import { TryAgain } from "@/components/try-again";

import { useGweet } from "../hooks/use-gweet";

import { Icons } from "@/components/icons";
import { Card } from "@/components/ui/card";
import { UserAvatar } from "@/components/user-avatar";
import { formatTimeElapsed } from "@/lib/utils";
import { Comments } from "./comments";
import { GweetActions } from "./gweet-actions";

export const GweetDetails = () => {
    const router = useRouter();
    const pathname = usePathname();
    const id = pathname?.split(`/`)[3] || ``;

    const { data: gweet, isLoading, isError } = useGweet(id);

    if (isLoading) {
        return <Icons.spinner className="h-4 w-4 animate-spin" />;
    }

    if (isError) {
        return <TryAgain />;
    }

    if (!isLoading && !isError && !gweet) {
        return <>Not Found!</>
    }

    console.log(`gweet`, gweet);

    return (
        <Card className="w-full h-full mt-12 p-2 xl:p-4 ">
            <div className="flex">
                {/* make gweet-author like twitter */}
                <UserAvatar
                    user={{ username: gweet.user.username, image: gweet.user.image }}
                    className="h-10 w-10"
                />
                <div className="flex items-center">
                    <h1 className="font-bold mr-2">{gweet.user.name}</h1>
                    <h1 className="text-sky-500 text-sm">
                        @{gweet.user.username}
                    </h1>
                </div>

                {/* {gweet?.replyToGweetId && (
                    <div className="">
                        <span className="">Replying to</span>
                        <button
                            onClick={(e) => {
                                e.stopPropagation();
                                router.push(`/${gweet?.replyToUserId}`);
                            }}
                            className=""
                        >
                            @{gweet?.replyToUserId}
                        </button>
                    </div>
                )} */}

                {gweet?.content && <h1>{gweet?.content}</h1>}

                {/* make gweet creation date like twitter */}
                {formatTimeElapsed(gweet.createdAt)}
                <div className="">
                    <GweetActions gweet={gweet} />
                </div>
            </div>

            <CreateGweetWrapper
                replyToUserId={gweet?.user?.email?.split(`@`)[0]}
                replyToGweetId={gweet?.id}
            />
            <div className="">
                <Comments gweetId={gweet?.id} />
            </div>
        </Card>
    );
};